==> ZenTaoPMS.max2.0.rc1.php7.0.zip: zentaopms/module/action/ext/model/class/oa.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPodFPRY955wm/dZmcz7/mQ3+g/ANUT68p+zSeBn2015xpO+pHhyFw7aKw1afUwDWAGQ88ODv
R3+6v8wiS7tv9+0m7aOGKW5IhGWECwQNTYtM8NAgdfANvHDEPOym3+VIOZwxBgFGe6lmjmIaXfMZ
Mmx6Du6lAE3IOWsneCX6sUddyaJ40JErxYAr9Qkp8KFQSrTD7q0aJWGGHytwHF1ulN+viQbVxGKb
gEFnwH7zlnINGxgJcN+FxA61OM0JlSFbPbXj5PSnO0nvKC7IjXFUUl/FH19k/GBlaLyuW5ACrqkG
GjNB+8IpRFAfrb+J61cIkPuXf47TkdEWUqLVJZylM1euB8f01CqrNMWwJmISItRsP/+KN6Ov5dpC
bYcDg2B9jNaleOWaimjJRQtxhjYukPMQzsZnopGNTKSK6r4Wc7J/E1D2A8wdBeD+qEOLsEyIabLR
gP3va5vRBQ3FFjvUOpIASAWwf2dqLoew+Kz7VyHspM18y4wpWC3tg6NRzTxZGLzs4gN7mJ976tUg
kDpIYXkzy5gH8ttm1qUeRoIYBZ/d1n8J8ZgJZtj7Sl9eTsAK61uzJh1CXiy1S66KWuZbVrzzogPe
vArAnz0iJLCo0adm7satAfoCQhdLjYoB+yWFGveiyrxRnMHGXf12nsjCVuE1O69k+rNPELq1bJAQ
+2EVGxqp9wGKXH02/YUuQJO+kGDjRC8HQzMA63P2eVLm1TJHBQ+bQQLawc4YAPtyHKErBsBcDDjd
AIGr0YqCEuhy1IXdwEe4RZETeHNk8v9XNKefQD2nG4r6O9/O1lAzpBXmN7DeObh+veylXQu1rj0a
ftY8usAoezNkPofuS5b1H1lB5AqmInWUi+HfDh7MmCj/HXZI+3KW+nAd8qXFcou1JHbZLwhL/DH/
9mXLq+HZ2ZdNXo560yAWHgiJqDVFIakduh4SC978ZL0CkwwVv2z0LIRBHMehZOcpIKmoG7ChTdx6
T3t+rkdxulBwKwvPco3Gjn2O+x/AWE/oPi0OI26md07ry8iZJvkDMAiGSliO73WSqE7jKLg/vWXj
HQyr6D0h/hqN6k396ahB2/Ym0lWVMM6pYiG0bmYuzxjov368naQFChik/+pz12GvQthbNMfGP8lq
tVKKJONHThLZ8rWb8IZsJQrE2c5hyY/mV84LrszuHtcojOr725Hnt4wSnoA/0AVbA6tGQCjKjAYD
ko8ngPKtm84D3YAypMoknslw9Nk6Cy/I3vcTHjQVCEsJKj4dwpCRsy7Ick/ABh2dMAf0YWmbOodu
X1+E+iYTx39pl0nak0scUOeZhBcwYHWQ4LcmkmwDAobQ7Ng1HWHZE2Ghr3NCd7o8B0EuAbkuqATb
yEJXH37udrNh59ToAmTxG4GzPR+lR4g8lRZPPK9PYiVLzZ/z1SM/0NOBNRCxetmq2Be5t+Wll4LE
ohlvII0Ymxbm07nui3eO7q/fhNyQXFS06ab1AhPY0ihCvSgkq9WjjaI0lDG=

==> ZenTaoPMS.max2.2.php5.3_5.6.zip: zentaopms/module/action/ext/model/class/oa.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPrizejIf1HSR2eWtz+0T804dmt+cPBoFaleE05tqNzhpEA7UV7T/l89G/LNJUWVPRw+8zI2u
8ea5PzpmS1FBb/KtmP7A1bwSx1hjI/VxLs9ApUvZcctte8N0xURnE+edpgkiwGDw6lBqEQVvAOXD
CaI2cHiuzzgLbNuSwnLSTccDGabLJ+5Al0cyMOxpSyLNMCu4/3HryNqT4CcZz/BH1ksRPwNWyQV6
pXJe6aH/YZS9XtUqlhb/cWicjNKN1+oYpEpCkvFs9RbbBWuUgjdhgzC4LWtBZ7dzbpDYsPhZz0W9
clWB2EDlMafCxjcD8qVHPOe/mFDoLf2TlmnlcMNHk8A3JBiLbUF2ahr8y+PGjHJ1nuH5Lt7uz2CE
1W2eK9HcOBC67HcNiBEEHwXG2P/l6xDiwTGR/vU+ZDZy4pL88N5snPqfZI5snaBkw7/KOQgzqVAp
zEmoNK5ESf/Zs3b91cmzTpGiwbVYLOIJZ6fAyl/kvUJYlTljkgECOfvfZT+QvljgiEZKnJg55j0+
WdNDRaQMZ6k6IUf/cdkyHjBY+hq0CMUIbEWvmNiKnqVsdhTRwpwS7Kp96wjotsw1PMLOZwfLWKXY
4DQJ4jvZoGz5Cs6bNOus0PJFacadcYMn+8vu9ePVEf5uGxeitqO1ExVklanBgTRffq6MutwOlmuj
gBqnhB+Yx17Bg7TmdibwxNwAWw5MakzwJoMI2fUZMT2OMn0IxoVwQNyYWhdTFeSrsmbJCJ3OVsPf
wMx0HuXT+Aan48AHHrM0m2vYeYDQdPe02zOnyf9l3iWglTq5gN/K4cXkEsyvJiFnQEVmfDn5ELKR
Vxz83F6SqDdBvR1yRnTzRhzdtIhtwiyk1pDKLUjw+9YvrkkSns8ka7QJhci05NbJXgCzGJRPP3k1
BzqE+E+t9m71XaHmfrrYlex5E/3J0Zj1ZsSGV1jPqIYcAL2mcTP7LqIP5GtNddlsMapRV8ufBewo
ZJggfVBS+rm=
